@@ -35,6 +35,7 @@
 #include "polynomial.h"
 #include "transformation.h"
 #include "substituteexpression.h"
+#include "expressionstream.h"
 
 // #define SCRIPT_PROFILER
 
@@ -166,22 +167,15 @@ void Analyzer::setExpression(const Expression & e)
 
 void Analyzer::importScript(QTextStream* stream)
 {
-	QString line;
-	for(bool done=!stream->atEnd(); done; done=!stream->atEnd() || !line.isEmpty()) {
-		line += stream->readLine(); // line of text excluding '\n'
-		line += '\n'; //make sure the \n is passed so that comments work properly
-		
-		if(Expression::isCompleteExpression(line) || stream->atEnd()) {
-			if(stream->atEnd() && !Expression::isCompleteExpression(line, true))
-				break;
-			
-			setExpression(Expression(line, Expression::isMathML(line)));
-			
+	ExpressionStream s(stream);
+	for(; !s.atEnd(); ) {
+		setExpression(s.next());
+		if(!s.isInterrupted())
 			calculate();
-			line.clear();
-			
-			if(!isCorrect())
-				break;
+		
+		if(!isCorrect()) {
+			m_err += s.lastLine();
+			break;
 		}
 	}
 }
@@ -1742,7 +1736,7 @@ Expression Analyzer::derivative(const QString& var)
 
 Expression Analyzer::dependenciesToLambda() const
 {
-	if(m_hasdeps) {
+	if(m_hasdeps && m_exp.tree()) {
 		QStringList deps=dependencies(m_exp.tree(), m_vars->keys());
 		Container* cc=new Container(Container::lambda);
 		foreach(const QString& dep, deps) {
@@ -1751,16 +1745,14 @@ Expression Analyzer::dependenciesToLambda() const
 			cc->appendBranch(bvar);
 		}
 		
-		Object* root=m_exp.tree()->copy();
+		const Object* root=m_exp.tree();
 		if(root->isContainer()) {
-			Container* c=static_cast<Container*>(root);
+			const Container* c=static_cast<const Container*>(root);
 			if(c->containerType()==Container::math) {
 				root=c->m_params.first();
-				c->m_params.first()=0;
-				delete c;
 			}
 		}
-		cc->appendBranch(root);
+		cc->appendBranch(root->copy());
 		
 		Container* math=new Container(Container::math);
 		math->appendBranch(cc);
@@ -1803,7 +1795,7 @@ double Analyzer::derivative(const QVector<Object*>& values )
 	
 	setStack(values);
 	
-	Expression e1(calculateLambda());
+	Expression e1(calc(m_exp.tree()));
 	if(!isCorrect())
 		return 0.;
 	
@@ -1818,7 +1810,7 @@ double Analyzer::derivative(const QVector<Object*>& values )
 		v->setValue(v->value()+h);
 	}
 	
-	Expression e2(calculateLambda());
+	Expression e2(calc(m_exp.tree()));
 	if(!isCorrect())
 		return 0.;
 	
