@@ -37,6 +37,8 @@
 #include <analitza/analyzer.h>
 #include <analitza/variables.h>
 
+using namespace Analitza;
+
 class HelpTip : public QLabel
 {
 	public:
@@ -454,11 +456,16 @@ bool ExpressionEdit::returnPress()
 	if(isMathML()) {
 		emit returnPressed();
 	} else {
-		bool complete = Analitza::Expression::isCompleteExpression(toPlainText());
-		haveToPress = !complete;
-		setCorrect(complete);
-		if(complete)
+		ExpLexer lex(toPlainText());
+		ExpressionParser ex;
+		ex.parse(&lex);
+		if(lex.isCompletelyRead()) {
+			setCorrect(true);
 			emit returnPressed();
+		} else {
+			setCorrect(false);
+			haveToPress=true;
+		}
 	}
 	m_helptip->hide();
 	return haveToPress;
@@ -475,9 +482,4 @@ Analitza::Expression ExpressionEdit::expression() const
 	return Analitza::Expression(text(), isMathML());
 }
 
-bool ExpressionEdit::isCorrect() const
-{
-	return m_correct && Analitza::Expression::isCompleteExpression(toPlainText());
-}
-
 #include "expressionedit.moc"
