@@ -27,15 +27,14 @@
 
 #include "analitzaguiexport.h"
 
+class OperatorsModel;
+class QKeyEvent;
+
 namespace Analitza
 {
 class Variables;
 class Analyzer;
 class Expression;
-}
-
-class OperatorsModel;
-class QKeyEvent;
 
 /**
 *	The expression edit widget is the one where we will input our expressions.
@@ -84,7 +83,7 @@ class ANALITZAGUI_EXPORT ExpressionEdit : public QPlainTextEdit
 		void setCorrect(bool cor);
 		
 		/** Checks whether it has been set to correct. */
-		bool isCorrect() const;
+		bool isCorrect() const { return m_correct; }
 		
 		/** Sets the string @p ans that will be entered when an operator is pressed. */
 		void setAns(const QString &ans) { m_ans=ans; }
@@ -168,4 +167,6 @@ class ANALITZAGUI_EXPORT ExpressionEdit : public QPlainTextEdit
 		int m_lineHeight;
 };
 
+}
+
 #endif
