@@ -22,8 +22,9 @@
 
 #include <QStandardItemModel>
 #include <QPointer>
-#include  <analitzaplot/plottingenums.h>
+
 #include "analitzaplotexport.h"
+
 namespace Analitza
 {
 class PlotsModel;
@@ -35,7 +36,7 @@ class ANALITZAPLOT_EXPORT PlotsDictionaryModel : public QStandardItemModel
 {
 Q_OBJECT
 public:
-    enum Roles { ExpressionRole = Qt::UserRole+1, FileRole };
+    enum Roles { ExpressionRole = Qt::UserRole+1, TitleRole, FileRole };
     PlotsDictionaryModel(QObject* parent = 0);
     ~PlotsDictionaryModel();
     
@@ -43,16 +44,15 @@ public:
     void setCurrentRow(int row);
     
     PlotsModel* plotModel();
-    void createDictionary(const QString& path);
-    void createAllDictionaries();
-    Analitza::Dimension dimension();
-
+    
 public slots:
     ///convenience class for currentRow
     void setCurrentIndex(const QModelIndex& idx);
     
 private:
     void updatePlotsModel();
+    void createDictionary(const QString& title, const QString& file);
+    
     QPointer<PlotsModel> m_plots;
     int m_currentItem;
 };
