@@ -45,12 +45,10 @@ PlotsModel::~PlotsModel()
 
 void PlotsModel::clear()
 {
-    if (!m_items.isEmpty()) {
-        beginRemoveRows(QModelIndex(), 0, m_items.count()-1);
-        qDeleteAll(m_items);
-        m_items.clear();
-        endRemoveRows();
-    }
+    beginRemoveRows(QModelIndex(), 0, m_items.count()-1);
+    qDeleteAll(m_items);
+    m_items.clear();
+    endRemoveRows();
 }
 
 Qt::ItemFlags PlotsModel::flags(const QModelIndex & index) const
@@ -144,10 +142,8 @@ bool PlotsModel::setData(const QModelIndex& index, const QVariant& value, int ro
                     PlotBuilder plot = PlotsFactory::self()->requestPlot(valexp, it->spaceDimension());
                     if (plot.canDraw()) {
                         if (m_items[index.row()]->expression() != valexp) {
-                            QColor color=it->color();
-                            QString name=it->name();
                             delete m_items[index.row()];
-                            m_items[index.row()] = plot.create(color, name);
+                            m_items[index.row()] = plot.create(it->color(), it->name());
                         }
                         
                         emit dataChanged(index, index);
@@ -203,14 +199,14 @@ void PlotsModel::addPlot(PlotItem* it)
     Q_ASSERT(it);
 
     beginInsertRows(QModelIndex(), m_items.count(), m_items.count());
+
     it->setModel(this);
     m_items.append(it);
-
+    
     if(FunctionGraph* g=dynamic_cast<FunctionGraph*>(it))
         g->setResolution(m_resolution);
-    endInsertRows();
 
-    m_namingCount++;
+    endInsertRows();
 }
 
 void PlotsModel::updatePlot(int row, PlotItem* it)
@@ -243,7 +239,8 @@ QModelIndex PlotsModel::indexForName(const QString& name)
 
 QString PlotsModel::freeId() const
 {
-	return "f"+QString::number(m_namingCount);
+	//TODO: figure out a better way
+	return "f"+QString::number(qrand()*rowCount());
 }
 
 void PlotsModel::setResolution(int res)
